# TemplateParams

Runtime type-check for **template preconditions**, including instance variables and local
variables. Think of this as the method signature of a template, as the **documentation**.

## Installation

1. Add it to your Gemfile and run `bundle`.

    ```ruby
    gem 'template_params'
    ```

2. If you're using rails, add a helper method.

   ```ruby
   # app/helpers/application_helper.rb
   def template_param(*args, &block)
     ::TemplateParams::Assertion.assert(*args, &block)
   end
   ```

  If you're not using rails, let me know how you install it, and I'll put that here.

## Usage

```ruby
# Assert `poll` is defined. If not, raises an `ArgumentError` (the "arguments"
# of the template are invalid).
template_param { poll }

# Assert `@course` is defined. Meaningless because instance variables are
# always defined.
template_param { @course }

# Assert `poll.is_a?(::Poll)`. If not, raises a `TypeError`.
template_param(::Poll) { poll }

# Assert `@course.is_a?(::Course)`
template_param(::Course) { @course }

# Assert `@course` is either a `::Course` or `nil`
template_param(::Course, allow_nil: true) { @course }
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run
`bundle exec rspec` to run the tests. You can also run `bin/console` for an
interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To
release a new version, update the version number in `version.rb`, and then run
`bundle exec rake release`, which will create a git tag for the version, push
git commits and tags, and push the `.gem` file to
[rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at
https://github.com/[USERNAME]/template_assertions. This project is intended to
be a safe, welcoming space for collaboration, and contributors are expected to
adhere to the [Contributor Covenant](contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT
License](http://opensource.org/licenses/MIT).
